package main

import ( 
    "github.com/gin-gonic/gin"
	"gorm.io/gorm/clause"
    "net/http"
    "log/slog"
)

func (env *Env) alive(c *gin.Context) {
    c.String(http.StatusOK, "yes!")
}

func (env *Env) getArtistByID(c *gin.Context) {
    artistID := c.Params.ByName("artistID")
    spotifyAuthToken := c.GetString("spotifyAuthToken")
	
    if artistID == "" || spotifyAuthToken == "Bearer " {
		c.JSON(http.StatusBadRequest, gin.H{"Error": "Could not find required parameters and/or required authentication tokens"})
		return
    }

	spotifyResponse, err := getSpotifyArtistData(artistID, spotifyAuthToken)
	if err != nil {
		slog.Error("[GOMUSIC] Failed to request latest spotify data from API", "Error", err)
		c.JSON(http.StatusInternalServerError, gin.H{"Error": "Failed to request the latest data from spotify API"})
		return
	}
    
	// Update DB here
	var genreList []Genre
	for _, val := range spotifyResponse.Genres {
		genreList = append(genreList, Genre {Name: val})
	}

	artistProfile := ArtistProfile{
		SpotifyID: spotifyResponse.ID,
		Name: spotifyResponse.Name,
		Popularity: spotifyResponse.Popularity,
		Genres: genreList,
	}

	// Create new record
	// Otherwise update values when artist with this SpotifyID already exists
	// Basically upsert
	dbResult := env.db.Clauses(clause.OnConflict{
		Columns: []clause.Column{{Name: "spotify_id"}},
		UpdateAll: true,
	}).Create(&artistProfile)

	if dbResult.Error != nil {
		slog.Error("[GOMUSIC] Failed to store response in local database", "Error", err)
	}

    // Send back our response data
    c.JSON(http.StatusOK, spotifyResponse)
}
